@@ -8,8 +8,10 @@ from great_expectations.data_context import DataContext
 
 from .util import (
     from_pandas,
+    measure_execution_time,
     read_csv,
     read_excel,
+    read_feather,
     read_json,
     read_parquet,
     read_pickle,
