@@ -1,17 +1,22 @@
 from great_expectations.core.usage_statistics.anonymizers.anonymizer import Anonymizer
-from great_expectations.datasource import Datasource, PandasDatasource, SqlAlchemyDatasource, SparkDFDatasource
+from great_expectations.datasource import (
+    Datasource,
+    PandasDatasource,
+    SparkDFDatasource,
+    SqlAlchemyDatasource,
+)
 
 
 class DatasourceAnonymizer(Anonymizer):
     def __init__(self, salt=None):
-        super(DatasourceAnonymizer, self).__init__(salt=salt)
+        super().__init__(salt=salt)
 
         # ordered bottom up in terms of inheritance order
         self._ge_classes = [
             PandasDatasource,
             SqlAlchemyDatasource,
             SparkDFDatasource,
-            Datasource
+            Datasource,
         ]
 
     def anonymize_datasource_info(self, name, config):
@@ -21,11 +26,7 @@ class DatasourceAnonymizer(Anonymizer):
         self.anonymize_object_info(
             anonymized_info_dict=anonymized_info_dict,
             ge_classes=self._ge_classes,
-            object_config=config
+            object_config=config,
         )
 
-        if anonymized_info_dict.get("parent_class") == "SqlAlchemyDatasource":
-            sqlalchemy_dialect = config["engine"]
-            anonymized_info_dict["sqlalchemy_dialect"] = sqlalchemy_dialect
-
         return anonymized_info_dict
