@@ -1,7 +1,4 @@
-try:
-    from collections.abc import Mapping
-except ImportError:
-    from collections import Mapping
+from collections.abc import Mapping
 
 
 # Updated from the stack overflow version below to concatenate lists
@@ -10,6 +7,10 @@ def nested_update(d, u):
     for k, v in u.items():
         if isinstance(v, Mapping):
             d[k] = nested_update(d.get(k, {}), v)
+        elif isinstance(v, set) or (k in d and isinstance(d[k], set)):
+            s1 = d.get(k, set())
+            s2 = v or set()
+            d[k] = s1 | s2
         elif isinstance(v, list) or (k in d and isinstance(d[k], list)):
             l1 = d.get(k, [])
             l2 = v or []
