@@ -7,6 +7,7 @@ from functools import wraps
 
 import numpy as np
 import pandas as pd
+
 from great_expectations.core import (
     ExpectationConfiguration,
     ExpectationSuite,
@@ -59,7 +60,7 @@ Usage::
 """
 
 
-class DocInherit(object):
+class DocInherit:
     def __init__(self, mthd):
         self.mthd = mthd
         self.name = mthd.__name__
