@@ -2,7 +2,11 @@ import logging
 import uuid
 from copy import deepcopy
 
-from marshmallow import (
+from ruamel.yaml import YAML
+from ruamel.yaml.comments import CommentedMap
+
+import great_expectations.exceptions as ge_exceptions
+from great_expectations.marshmallow__shade import (
     INCLUDE,
     Schema,
     ValidationError,
@@ -11,10 +15,6 @@ from marshmallow import (
     post_load,
     validates_schema,
 )
-from ruamel.yaml import YAML
-from ruamel.yaml.comments import CommentedMap
-
-import great_expectations.exceptions as ge_exceptions
 from great_expectations.types import DictDot
 from great_expectations.types.configurations import ClassConfigSchema
 
@@ -420,7 +420,7 @@ class DataContextConfigSchema(Schema):
         elif data["config_version"] < MINIMUM_SUPPORTED_CONFIG_VERSION:
             raise ge_exceptions.UnsupportedConfigVersionError(
                 "You appear to have an invalid config version ({}).\n    The version number must be at least {}. "
-                "Please see the migration guide at https://docs.greatexpectations.io/en/latest/how_to_guides/migrating_versions.html".format(
+                "Please see the migration guide at https://docs.greatexpectations.io/en/latest/guides/how_to_guides/migrating_versions.html".format(
                     data["config_version"], MINIMUM_SUPPORTED_CONFIG_VERSION
                 ),
             )
