@@ -18,7 +18,7 @@ logger = logging.getLogger(__name__)
 
 
 class S3GlobReaderBatchKwargsGenerator(BatchKwargsGenerator):
-    """
+    r"""
     S3 BatchKwargGenerator provides support for generating batches of data from an S3 bucket. For the S3 batch kwargs generator, assets must
     be individually defined using a prefix and glob, although several additional configuration parameters are available
     for assets (see below).
@@ -43,7 +43,7 @@ class S3GlobReaderBatchKwargsGenerator(BatchKwargsGenerator):
                   my_first_asset:
                     prefix: my_first_asset/
                     regex_filter: .*  # The regex filter will filter the results returned by S3 for the key and prefix to only those matching the regex
-                    dictionary_assets: True
+                    directory_assets: True # if True, the contents of the directory will be treated as one batch. Notice that this option does not work with Pandas, since Pandas does not support loading multiple files from and S3 bucket into a data frame.
                   access_logs:
                     prefix: access_logs
                     regex_filter: access_logs/2019.*\.csv.gz
@@ -51,6 +51,14 @@ class S3GlobReaderBatchKwargsGenerator(BatchKwargsGenerator):
                     max_keys: 100
     """
 
+    recognized_batch_parameters = {
+        "data_asset_name",
+        "partition_id",
+        "reader_method",
+        "reader_options",
+        "limit",
+    }
+
     # FIXME add tests for new partitioner functionality
     def __init__(
         self,
@@ -77,9 +85,7 @@ class S3GlobReaderBatchKwargsGenerator(BatchKwargsGenerator):
             boto3_options: dictionary of key-value pairs to use when creating boto3 client or resource objects
             max_keys: the maximum number of keys to fetch in a single list_objects request to s3
         """
-        super(S3GlobReaderBatchKwargsGenerator, self).__init__(
-            name, datasource=datasource
-        )
+        super().__init__(name, datasource=datasource)
         if reader_options is None:
             reader_options = {}
 
@@ -119,7 +125,9 @@ class S3GlobReaderBatchKwargsGenerator(BatchKwargsGenerator):
     def get_available_data_asset_names(self):
         return {"names": [(key, "file") for key in self._assets.keys()]}
 
-    def _get_iterator(self, data_asset_name, reader_options=None, limit=None):
+    def _get_iterator(
+        self, data_asset_name, reader_method=None, reader_options=None, limit=None
+    ):
         logger.debug(
             "Beginning S3GlobReaderBatchKwargsGenerator _get_iterator for data_asset_name: %s"
             % data_asset_name
@@ -128,6 +136,7 @@ class S3GlobReaderBatchKwargsGenerator(BatchKwargsGenerator):
         if data_asset_name not in self._assets:
             batch_kwargs = {
                 "data_asset_name": data_asset_name,
+                "reader_method": reader_method,
                 "reader_options": reader_options,
                 "limit": limit,
             }
@@ -143,6 +152,7 @@ class S3GlobReaderBatchKwargsGenerator(BatchKwargsGenerator):
         return self._build_asset_iterator(
             asset_config=asset_config,
             iterator_dict=self._iterators[data_asset_name],
+            reader_method=reader_method,
             reader_options=reader_options,
             limit=limit,
         )
@@ -153,56 +163,66 @@ class S3GlobReaderBatchKwargsGenerator(BatchKwargsGenerator):
                 path, reader_options=reader_options, limit=limit
             )
 
-    # TODO: deprecate generator_asset argument
-    def build_batch_kwargs_from_partition_id(
-        self,
-        generator_asset=None,
-        data_asset_name=None,
-        partition_id=None,
-        reader_options=None,
-        limit=None,
-    ):
-        assert (generator_asset and not data_asset_name) or (
-            not generator_asset and data_asset_name
-        ), "Please provide either generator_asset or data_asset_name."
-        if generator_asset:
-            warnings.warn(
-                "The 'generator_asset' argument will be deprecated and renamed to 'data_asset_name'. "
-                "Please update code accordingly.",
-                DeprecationWarning,
-            )
-            data_asset_name = generator_asset
+    def _build_batch_kwargs(self, batch_parameters):
         try:
-            asset_config = self._assets[data_asset_name]
+            data_asset_name = batch_parameters.pop("data_asset_name")
         except KeyError:
-            raise GreatExpectationsError(
-                "No asset config found for asset %s" % data_asset_name
+            raise BatchKwargsError(
+                "Unable to build BatchKwargs: no name provided in batch_parameters.",
+                batch_kwargs=batch_parameters,
             )
-        if data_asset_name not in self._iterators:
-            self._iterators[data_asset_name] = {}
 
-        iterator_dict = self._iterators[data_asset_name]
-        batch_kwargs = None
-        for key in self._get_asset_options(data_asset_name, iterator_dict):
-            if self._partitioner(key=key, asset_config=asset_config) == partition_id:
-                batch_kwargs = self._build_batch_kwargs(
-                    key=key,
-                    asset_config=asset_config,
-                    reader_options=reader_options,
-                    limit=limit,
+        partition_id = batch_parameters.pop("partition_id", None)
+        batch_kwargs = self._datasource.process_batch_parameters(batch_parameters)
+
+        if partition_id:
+            try:
+                asset_config = self._assets[data_asset_name]
+            except KeyError:
+                raise GreatExpectationsError(
+                    "No asset config found for asset %s" % data_asset_name
+                )
+            if data_asset_name not in self._iterators:
+                self._iterators[data_asset_name] = {}
+
+            iterator_dict = self._iterators[data_asset_name]
+            for key in self._get_asset_options(asset_config, iterator_dict):
+                if (
+                    self._partitioner(key=key, asset_config=asset_config)
+                    == partition_id
+                ):
+                    batch_kwargs = self._build_batch_kwargs_from_key(
+                        key=key,
+                        asset_config=asset_config,
+                        reader_options=batch_parameters.get(
+                            "reader_options"
+                        ),  # handled in generator
+                        limit=batch_kwargs.get(
+                            "limit"
+                        ),  # may have been processed from datasource
+                    )
+
+            if batch_kwargs is None:
+                raise BatchKwargsError(
+                    "Unable to identify partition %s for asset %s"
+                    % (partition_id, data_asset_name),
+                    {data_asset_name: data_asset_name, partition_id: partition_id},
                 )
 
-        if batch_kwargs is None:
-            raise BatchKwargsError(
-                "Unable to identify partition %s for asset %s"
-                % (partition_id, data_asset_name),
-                {data_asset_name: data_asset_name, partition_id: partition_id},
+            return batch_kwargs
+
+        else:
+            return self.yield_batch_kwargs(
+                data_asset_name=data_asset_name, **batch_parameters, **batch_kwargs
             )
 
-        return batch_kwargs
-
-    def _build_batch_kwargs(
-        self, key, asset_config=None, reader_options=None, limit=None
+    def _build_batch_kwargs_from_key(
+        self,
+        key,
+        asset_config=None,
+        reader_method=None,
+        reader_options=None,
+        limit=None,
     ):
         batch_kwargs = {
             "s3": "s3a://" + self.bucket + "/" + key,
@@ -217,6 +237,8 @@ class S3GlobReaderBatchKwargsGenerator(BatchKwargsGenerator):
             batch_kwargs["reader_method"] = self._reader_method
         if asset_config.get("reader_method"):
             batch_kwargs["reader_method"] = asset_config.get("reader_method")
+        if reader_method is not None:
+            batch_kwargs["reader_method"] = reader_method
 
         if limit:
             batch_kwargs["limit"] = limit
@@ -279,24 +301,31 @@ class S3GlobReaderBatchKwargsGenerator(BatchKwargsGenerator):
                 keys,
             )
         ]
-        for key in keys:
-            yield key
+        yield from keys
 
         if asset_options["IsTruncated"]:
             iterator_dict["continuation_token"] = asset_options["NextContinuationToken"]
             # Recursively fetch more
-            for key in self._get_asset_options(asset_config, iterator_dict):
-                yield key
+            yield from self._get_asset_options(asset_config, iterator_dict)
         elif "continuation_token" in iterator_dict:
             # Make sure we clear the token once we've gotten fully through
             del iterator_dict["continuation_token"]
 
     def _build_asset_iterator(
-        self, asset_config, iterator_dict, reader_options=None, limit=None
+        self,
+        asset_config,
+        iterator_dict,
+        reader_method=None,
+        reader_options=None,
+        limit=None,
     ):
         for key in self._get_asset_options(asset_config, iterator_dict):
-            yield self._build_batch_kwargs(
-                key, asset_config, reader_options=reader_options, limit=limit
+            yield self._build_batch_kwargs_from_key(
+                key,
+                asset_config,
+                reader_method=None,
+                reader_options=reader_options,
+                limit=limit,
             )
 
     # TODO: deprecate generator_asset argument
@@ -318,7 +347,7 @@ class S3GlobReaderBatchKwargsGenerator(BatchKwargsGenerator):
         asset_config = self._assets[data_asset_name]
         available_ids = [
             self._partitioner(key=key, asset_config=asset_config)
-            for key in self._get_asset_options(data_asset_name, iterator_dict)
+            for key in self._get_asset_options(asset_config, iterator_dict)
         ]
         return available_ids
 
