@@ -1,10 +1,12 @@
-import pickle
 import hashlib
+import pickle
 from urllib.parse import urlparse
+
 import pandas as pd
 
+
 # S3Url class courtesy: https://stackoverflow.com/questions/42641315/s3-urls-get-bucket-name-and-path
-class S3Url(object):
+class S3Url:
     """
     >>> s = S3Url("s3://bucket/hello/world")
     >>> s.bucket
@@ -39,9 +41,9 @@ class S3Url(object):
     @property
     def key(self):
         if self._parsed.query:
-            return self._parsed.path.lstrip('/') + '?' + self._parsed.query
+            return self._parsed.path.lstrip("/") + "?" + self._parsed.query
         else:
-            return self._parsed.path.lstrip('/')
+            return self._parsed.path.lstrip("/")
 
     @property
     def url(self):
