@@ -1,7 +1,7 @@
 import importlib
 import json
 
-from marshmallow import ValidationError
+from great_expectations.marshmallow__shade import ValidationError
 
 
 class GreatExpectationsError(Exception):
@@ -16,6 +16,12 @@ class GreatExpectationsValidationError(ValidationError, GreatExpectationsError):
         self.messages = validation_error.messages
 
 
+class SuiteEditNotebookCustomTemplateModuleNotFoundError(ModuleNotFoundError):
+    def __init__(self, custom_module):
+        message = f"The custom module '{custom_module}' could not be found"
+        super().__init__(message)
+
+
 class DataContextError(GreatExpectationsError):
     pass
 
@@ -40,7 +46,7 @@ class ParserError(GreatExpectationsError):
     pass
 
 
-class InvalidConfigurationYamlError(GreatExpectationsError):
+class InvalidConfigurationYamlError(DataContextError):
     pass
 
 
@@ -126,6 +132,10 @@ class StoreError(DataContextError):
     pass
 
 
+class InvalidKeyError(StoreError):
+    pass
+
+
 class InvalidCacheValueError(GreatExpectationsError):
     def __init__(self, result_dict):
         template = """\
@@ -252,12 +262,15 @@ class BatchKwargsError(DataContextError):
 
 class DatasourceInitializationError(GreatExpectationsError):
     def __init__(self, datasource_name, message):
-        self.message = "Cannot initialize datasource %s, error: %s" % (
-            datasource_name,
-            message,
+        self.message = "Cannot initialize datasource {}, error: {}".format(
+            datasource_name, message,
         )
         super().__init__(self.message)
 
 
+class DatasourceKeyPairAuthBadPassphraseError(DatasourceInitializationError):
+    pass
+
+
 class InvalidConfigValueTypeError(DataContextError):
     pass
