@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 import datetime
 import logging
 from itertools import chain
@@ -10,7 +8,7 @@ from IPython.display import display
 logger = logging.getLogger(__name__)
 
 
-class ExpectationExplorer(object):
+class ExpectationExplorer:
     def __init__(self):
         self.state = {"data_assets": {}}
         self.expectation_kwarg_field_names = {
@@ -113,6 +111,7 @@ class ExpectationExplorer(object):
                 "max_value",
             ],
             "expect_table_columns_to_match_ordered_list": ["column_list"],
+            "expect_table_columns_to_match_set": ["column_set", "exact_match"],
             ####
             "expect_column_pair_values_to_be_equal": ["ignore_row_if"],
             "expect_column_pair_values_A_to_be_greater_than_B": [
@@ -124,7 +123,8 @@ class ExpectationExplorer(object):
                 "value_pairs_set",
                 "ignore_row_if",
             ],
-            "expect_multicolumn_values_to_be_unique": ["ignore_row_if"],
+            "expect_compound_columns_to_be_unique": ["ignore_row_if"],
+            "expect_select_column_values_to_be_unique_within_record": ["ignore_row_if"],
             "expect_column_values_to_be_of_type": ["type_", "mostly"],
             "expect_column_values_to_be_in_type_list": ["type_list", "mostly"],
             "expect_column_kl_divergence_to_be_less_than": [
@@ -997,7 +997,7 @@ class ExpectationExplorer(object):
         expectation_feedback_widget = expectation_state["expectation_feedback_widget"]
         expectation_type = expectation_state["expectation_type"]
         regex_widget = self.generate_text_area_widget(
-            value=regex, description="regex", placeholder="e.g. ([A-Z])\w+"
+            value=regex, description="regex", placeholder=r"e.g. ([A-Z])\w+"
         )
 
         @expectation_feedback_widget.capture(clear_output=True)
@@ -1727,7 +1727,7 @@ class ExpectationExplorer(object):
         for result_title, result_value in result.items():
             result_detail_widgets.append(
                 widgets.HTML(
-                    value="<span><strong>{0}: </strong>{1:.2f}</span>".format(
+                    value="<span><strong>{}: </strong>{:.2f}</span>".format(
                         result_title, result_value
                     )
                     if type(result_value) is float
