@@ -1,9 +1,10 @@
-from .profiling_overview_table_content_block import ProfilingOverviewTableContentBlockRenderer
-from .bullet_list_content_block import (
-    ExpectationSuiteBulletListContentBlockRenderer,
-)
 from great_expectations.render.renderer.content_block.validation_results_table_content_block import (
     ValidationResultsTableContentBlockRenderer,
 )
+
+from .bullet_list_content_block import ExpectationSuiteBulletListContentBlockRenderer
 from .exception_list_content_block import ExceptionListContentBlockRenderer
 from .expectation_string import ExpectationStringRenderer
+from .profiling_overview_table_content_block import (
+    ProfilingOverviewTableContentBlockRenderer,
+)
