@@ -2,7 +2,7 @@ import logging
 import warnings
 from collections import OrderedDict
 
-from dateutil.parser import ParserError, parse
+from dateutil.parser import parse
 
 from great_expectations.core import RunIdentifier
 from great_expectations.data_asset import DataAsset
@@ -25,7 +25,7 @@ logger = logging.getLogger(__name__)
 logger = logging.getLogger(__name__)
 
 
-class ValidationOperator(object):
+class ValidationOperator:
     """
     The base class of all validation operators.
 
@@ -117,6 +117,7 @@ An instance of ActionListValidationOperator is included in the default configura
           # put the actual webhook URL in the uncommitted/config_variables.yml file
           slack_webhook: ${validation_notification_slack_webhook}
           notify_on: all # possible values: "all", "failure", "success"
+          notify_with: optional list of DataDocs sites (ie local_site or gcs_site") to include in Slack notification. Will default to including all configured DataDocs sites.
           renderer:
             module_name: great_expectations.render.renderer.slack_renderer
             class_name: SlackRenderer
@@ -284,6 +285,7 @@ The ``run`` method returns a ValidationOperatorResult object:
         run_time=None,
         result_format=None,
     ):
+
         assert not (run_id and run_name) and not (
             run_id and run_time
         ), "Please provide either a run_id or run_name and/or run_time."
@@ -297,7 +299,7 @@ The ``run`` method returns a ValidationOperatorResult object:
             )
             try:
                 run_time = parse(run_id)
-            except (ParserError, TypeError):
+            except (ValueError, TypeError):
                 pass
             run_id = RunIdentifier(run_name=run_id, run_time=run_time)
         elif isinstance(run_id, dict):
@@ -331,6 +333,7 @@ The ``run`` method returns a ValidationOperatorResult object:
                 batch_validation_result,
                 run_id,
             )
+
             run_result_obj["actions_results"] = batch_actions_results
             run_results[validation_result_id] = run_result_obj
 
@@ -378,11 +381,17 @@ The ``run`` method returns a ValidationOperatorResult object:
                     validation_result_suite_identifier=validation_result_id,
                     validation_result_suite=batch_validation_result,
                     data_asset=batch,
+                    payload=batch_actions_results,
                 )
 
+                # add action_result
                 batch_actions_results[action["name"]] = (
                     {} if action_result is None else action_result
                 )
+                batch_actions_results[action["name"]]["class"] = action["action"][
+                    "class_name"
+                ]
+
             except Exception as e:
                 logger.exception(
                     "Error running action with name {}".format(action["name"])
@@ -512,6 +521,7 @@ The value of "success" is True if no critical expectation suites ("failure") fai
                 "stop_on_first_error": ...,
                 "slack_webhook": ...,
                 "notify_on": ...,
+                "notify_with":...,
             },
         },
         "run_results": {
@@ -539,6 +549,7 @@ The value of "success" is True if no critical expectation suites ("failure") fai
         stop_on_first_error=False,
         slack_webhook=None,
         notify_on="all",
+        notify_with=None,
         result_format={"result_format": "SUMMARY"},
     ):
         super().__init__(data_context, action_list, name)
@@ -556,6 +567,7 @@ The value of "success" is True if no critical expectation suites ("failure") fai
 
         self.slack_webhook = slack_webhook
         self.notify_on = notify_on
+        self.notify_with = notify_with
         result_format = parse_result_format(result_format)
         assert result_format["result_format"] in [
             "BOOLEAN_ONLY",
@@ -579,6 +591,7 @@ The value of "success" is True if no critical expectation suites ("failure") fai
                     "stop_on_first_error": self.stop_on_first_error,
                     "slack_webhook": self.slack_webhook,
                     "notify_on": self.notify_on,
+                    "notify_with": self.notify_with,
                     "result_format": self.result_format,
                 },
             }
@@ -700,7 +713,7 @@ The value of "success" is True if no critical expectation suites ("failure") fai
             )
             try:
                 run_time = parse(run_id)
-            except (ParserError, TypeError):
+            except (ValueError, TypeError):
                 pass
             run_id = RunIdentifier(run_name=run_id, run_time=run_time)
         elif isinstance(run_id, dict):
